==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dir_1bab67e0e9893324e92f7ce98fde9362.js <==
var dir_1bab67e0e9893324e92f7ce98fde9362 =
[
    [ "address.cpp", "d0/d0d/address_8cpp.html", "d0/d0d/address_8cpp" ],
    [ "address.h", "d9/d9b/address_8h.html", "d9/d9b/address_8h" ],
    [ "config.h", "db/d16/config_8h.html", "db/d16/config_8h" ],
    [ "core.cpp", "da/de0/core_8cpp.html", "da/de0/core_8cpp" ],
    [ "core.h", "d5/dc4/core_8h.html", "d5/dc4/core_8h" ],
    [ "game.h", "d2/dd5/game_8h.html", "d2/dd5/game_8h" ],
    [ "host.cpp", "d8/d5e/host_8cpp.html", "d8/d5e/host_8cpp" ],
    [ "host.h", "df/ded/host_8h.html", "df/ded/host_8h" ],
    [ "os_abstraction.h", "d5/d8f/os__abstraction_8h.html", "d5/d8f/os__abstraction_8h" ],
    [ "packet.cpp", "d3/dae/packet_8cpp.html", null ],
    [ "packet.h", "d3/d76/packet_8h.html", "d3/d76/packet_8h" ],
    [ "tcp.cpp", "d9/d14/tcp_8cpp.html", null ],
    [ "tcp.h", "d8/da5/tcp_8h.html", "d8/da5/tcp_8h" ],
    [ "tcp_admin.cpp", "d9/d18/tcp__admin_8cpp.html", "d9/d18/tcp__admin_8cpp" ],
    [ "tcp_admin.h", "d0/dec/tcp__admin_8h.html", "d0/dec/tcp__admin_8h" ],
    [ "tcp_connect.cpp", "d9/d51/tcp__connect_8cpp.html", "d9/d51/tcp__connect_8cpp" ],
    [ "tcp_content.cpp", "d7/d76/tcp__content_8cpp.html", "d7/d76/tcp__content_8cpp" ],
    [ "tcp_content.h", "dd/dc7/tcp__content_8h.html", "dd/dc7/tcp__content_8h" ],
    [ "tcp_game.cpp", "df/d3f/tcp__game_8cpp.html", null ],
    [ "tcp_game.h", "d9/dc7/tcp__game_8h.html", "d9/dc7/tcp__game_8h" ],
    [ "tcp_http.cpp", "da/d81/tcp__http_8cpp.html", "da/d81/tcp__http_8cpp" ],
    [ "tcp_http.h", "d1/d1d/tcp__http_8h.html", [
      [ "HTTPCallback", "d8/d33/structHTTPCallback.html", "d8/d33/structHTTPCallback" ],
      [ "NetworkHTTPSocketHandler", "db/d24/classNetworkHTTPSocketHandler.html", "db/d24/classNetworkHTTPSocketHandler" ],
      [ "NetworkHTTPContentConnecter", "d8/d73/classNetworkHTTPContentConnecter.html", "d8/d73/classNetworkHTTPContentConnecter" ]
    ] ],
    [ "tcp_listen.h", "dd/d7a/tcp__listen_8h.html", [
      [ "TCPListenHandler", "d4/d29/classTCPListenHandler.html", "d4/d29/classTCPListenHandler" ]
    ] ],
    [ "udp.cpp", "d6/d64/udp_8cpp.html", null ],
    [ "udp.h", "d2/da7/udp_8h.html", "d2/da7/udp_8h" ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dir_1bab67e0e9893324e92f7ce98fde9362.js <==
var dir_1bab67e0e9893324e92f7ce98fde9362 =
[
    [ "address.cpp", "d0/d0d/address_8cpp.html", "d0/d0d/address_8cpp" ],
    [ "address.h", "d9/d9b/address_8h.html", "d9/d9b/address_8h" ],
    [ "config.h", "db/d16/config_8h.html", "db/d16/config_8h" ],
    [ "core.cpp", "da/de0/core_8cpp.html", "da/de0/core_8cpp" ],
    [ "core.h", "d5/dc4/core_8h.html", "d5/dc4/core_8h" ],
    [ "game.h", "d2/dd5/game_8h.html", "d2/dd5/game_8h" ],
    [ "host.cpp", "d8/d5e/host_8cpp.html", "d8/d5e/host_8cpp" ],
    [ "host.h", "df/ded/host_8h.html", "df/ded/host_8h" ],
    [ "os_abstraction.h", "d5/d8f/os__abstraction_8h.html", "d5/d8f/os__abstraction_8h" ],
    [ "packet.cpp", "d3/dae/packet_8cpp.html", null ],
    [ "packet.h", "d3/d76/packet_8h.html", "d3/d76/packet_8h" ],
    [ "tcp.cpp", "d9/d14/tcp_8cpp.html", null ],
    [ "tcp.h", "d8/da5/tcp_8h.html", "d8/da5/tcp_8h" ],
    [ "tcp_admin.cpp", "d9/d18/tcp__admin_8cpp.html", null ],
    [ "tcp_admin.h", "d0/dec/tcp__admin_8h.html", "d0/dec/tcp__admin_8h" ],
    [ "tcp_connect.cpp", "d9/d51/tcp__connect_8cpp.html", "d9/d51/tcp__connect_8cpp" ],
    [ "tcp_content.cpp", "d7/d76/tcp__content_8cpp.html", "d7/d76/tcp__content_8cpp" ],
    [ "tcp_content.h", "dd/dc7/tcp__content_8h.html", "dd/dc7/tcp__content_8h" ],
    [ "tcp_game.cpp", "df/d3f/tcp__game_8cpp.html", null ],
    [ "tcp_game.h", "d9/dc7/tcp__game_8h.html", "d9/dc7/tcp__game_8h" ],
    [ "tcp_http.cpp", "da/d81/tcp__http_8cpp.html", "da/d81/tcp__http_8cpp" ],
    [ "tcp_http.h", "d1/d1d/tcp__http_8h.html", [
      [ "HTTPCallback", "d8/d33/structHTTPCallback.html", "d8/d33/structHTTPCallback" ],
      [ "NetworkHTTPSocketHandler", "db/d24/classNetworkHTTPSocketHandler.html", "db/d24/classNetworkHTTPSocketHandler" ],
      [ "NetworkHTTPContentConnecter", "d8/d73/classNetworkHTTPContentConnecter.html", "d8/d73/classNetworkHTTPContentConnecter" ]
    ] ],
    [ "tcp_listen.h", "dd/d7a/tcp__listen_8h.html", [
      [ "TCPListenHandler", "d4/d29/classTCPListenHandler.html", "d4/d29/classTCPListenHandler" ]
    ] ],
    [ "udp.cpp", "d6/d64/udp_8cpp.html", null ],
    [ "udp.h", "d2/da7/udp_8h.html", "d2/da7/udp_8h" ]
];
